Module host

Module host 

Platform host — abstract interface from view threads to the main thread.

Like Chrome’s WidgetHost / FrameWidgetHost Mojo interfaces. The view thread communicates back to the main thread through this trait, never through windowing-backend types (winit, SDL2, etc.).

The windowing backend (e.g., kozan-winit) provides the concrete implementation.

Traits

PlatformHost
The interface from a view thread back to the main thread.