View thread types — handle and errors.
The event loop and spawn logic live in pipeline/.
Structs
- View
Thread Handle - Handle to a running view thread.
Enums
- Spawn
Error - Error returned when a thread fails to start.
View thread types — handle and errors.
The event loop and spawn logic live in pipeline/.